@@ -497,7 +497,7 @@ class CurveBuilder:
         elif curve_type == CurveType.ARC:
             curves = self.arcs_from_points(points)
         elif curve_type == CurveType.CUBICBEZIER:
-            leftover_count = (len(self.current_points) - 1) % 3 if len(self.current_points) >= 4 else len(self.current_points)
+            leftover_count = (len(points) - 1) % 3 if len(points) >= 4 else len(points)
             leftover_points = points[-leftover_count:] if leftover_count != 0 else leftover_points
             used_points = points[:-leftover_count] if leftover_count != 0 else points
             curves = self.cubicbeziers_from_points(used_points)
