@@ -21,6 +21,9 @@ class Toggleable():
     def copy(self):
         return type(self)(values=self.value, starting_index=self.index)
 
+    def set_value(self, value):
+        self.index = self.values.index(value)
+
 class BooleanToggleable(Toggleable):
     def __init__(self, default: bool = True):
         if default:
@@ -53,4 +56,8 @@ class IntegerRangeToggleable(Toggleable):
 
 class EnumToggleable(Toggleable):
     def __init__(self, enum_type):
-        Toggleable.__init__(self, [val for val in enum_type.__members__.values()], 0)
\ No newline at end of file
+        self.enum = enum_type
+        Toggleable.__init__(self, [val for val in enum_type.__members__.values()], 0)
+
+    def set_value(self, enum_val):
+        self.index = self.values.index(enum_val)
\ No newline at end of file
